@@ -7,6 +7,8 @@ import (
 	"testing"
 	"unicode/utf8"
 
+	"github.com/evanw/esbuild/internal/config"
+	"github.com/evanw/esbuild/internal/helpers"
 	"github.com/evanw/esbuild/internal/logger"
 	"github.com/evanw/esbuild/internal/test"
 )
@@ -32,7 +34,7 @@ func assertEqualStrings(t *testing.T, a string, b string) {
 
 func lexToken(t *testing.T, contents string) T {
 	log := logger.NewDeferLog(logger.DeferLogNoVerboseOrDebug)
-	lexer := NewLexer(log, test.SourceForTest(contents))
+	lexer := NewLexer(log, test.SourceForTest(contents), config.TSOptions{})
 	return lexer.Token
 }
 
@@ -48,7 +50,7 @@ func expectLexerError(t *testing.T, contents string, expected string) {
 					panic(r)
 				}
 			}()
-			NewLexer(log, test.SourceForTest(contents))
+			NewLexer(log, test.SourceForTest(contents), config.TSOptions{})
 		}()
 		msgs := log.Done()
 		text := ""
@@ -78,12 +80,12 @@ func expectHashbang(t *testing.T, contents string, expected string) {
 					panic(r)
 				}
 			}()
-			return NewLexer(log, test.SourceForTest(contents))
+			return NewLexer(log, test.SourceForTest(contents), config.TSOptions{})
 		}()
 		msgs := log.Done()
 		test.AssertEqual(t, len(msgs), 0)
 		test.AssertEqual(t, lexer.Token, THashbang)
-		test.AssertEqual(t, lexer.Identifier, expected)
+		test.AssertEqual(t, lexer.Identifier.String, expected)
 	})
 }
 
@@ -106,12 +108,12 @@ func expectIdentifier(t *testing.T, contents string, expected string) {
 					panic(r)
 				}
 			}()
-			return NewLexer(log, test.SourceForTest(contents))
+			return NewLexer(log, test.SourceForTest(contents), config.TSOptions{})
 		}()
 		msgs := log.Done()
 		test.AssertEqual(t, len(msgs), 0)
 		test.AssertEqual(t, lexer.Token, TIdentifier)
-		test.AssertEqual(t, lexer.Identifier, expected)
+		test.AssertEqual(t, lexer.Identifier.String, expected)
 	})
 }
 
@@ -145,7 +147,7 @@ func expectNumber(t *testing.T, contents string, expected float64) {
 					panic(r)
 				}
 			}()
-			return NewLexer(log, test.SourceForTest(contents))
+			return NewLexer(log, test.SourceForTest(contents), config.TSOptions{})
 		}()
 		msgs := log.Done()
 		test.AssertEqual(t, len(msgs), 0)
@@ -352,12 +354,12 @@ func expectBigInteger(t *testing.T, contents string, expected string) {
 					panic(r)
 				}
 			}()
-			return NewLexer(log, test.SourceForTest(contents))
+			return NewLexer(log, test.SourceForTest(contents), config.TSOptions{})
 		}()
 		msgs := log.Done()
 		test.AssertEqual(t, len(msgs), 0)
 		test.AssertEqual(t, lexer.Token, TBigIntegerLiteral)
-		test.AssertEqual(t, lexer.Identifier, expected)
+		test.AssertEqual(t, lexer.Identifier.String, expected)
 	})
 }
 
@@ -407,13 +409,13 @@ func expectString(t *testing.T, contents string, expected string) {
 					panic(r)
 				}
 			}()
-			return NewLexer(log, test.SourceForTest(contents))
+			return NewLexer(log, test.SourceForTest(contents), config.TSOptions{})
 		}()
 		text := lexer.StringLiteral()
 		msgs := log.Done()
 		test.AssertEqual(t, len(msgs), 0)
 		test.AssertEqual(t, lexer.Token, TStringLiteral)
-		assertEqualStrings(t, UTF16ToString(text), expected)
+		assertEqualStrings(t, helpers.UTF16ToString(text), expected)
 	})
 }
 
@@ -429,7 +431,7 @@ func expectLexerErrorString(t *testing.T, contents string, expected string) {
 					panic(r)
 				}
 			}()
-			lexer := NewLexer(log, test.SourceForTest(contents))
+			lexer := NewLexer(log, test.SourceForTest(contents), config.TSOptions{})
 			lexer.StringLiteral()
 		}()
 		msgs := log.Done()
